@@ -8,7 +8,7 @@ package Connector;
 
 use 5.008_008;  # This is the earliest version we've tested on
 
-our $VERSION = '1.12';
+our $VERSION = '1.13';
 
 use strict;
 use warnings;
@@ -299,7 +299,7 @@ sub exists {
 sub get { shift; die "No get() method defined";  };
 sub get_list { shift; die "No get_list() method defined";  };
 sub get_hash { shift; die "No get_hash() method defined";  };
-sub get_meta { shift; die "No get_hash() method defined";  };
+sub get_meta { shift; die "No get_meta() method defined";  };
 sub get_reference { shift; die "No get_hash() method defined";  };
 sub set { shift;  die "No set() method defined";  };
 
